@@ -230,7 +230,9 @@ def get_dataset(country, from_, to_, keyword=None):
     
     return df
     
-    
+def export_to_csv(df, name="default"):
+    df.to_csv(name,sep=";")
+    print("dataset saved as"+name+".csv")
     
     
     
