@@ -12,6 +12,7 @@ ngram_vars={
     "nlp":"",
     "matcher":""
 }
+plt.rcParams['figure.figsize'] = [6, 8]
 def setup():
     global ngram_vars
     ngram_vars["nlp"] = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
@@ -36,10 +37,10 @@ else:
 def get_keywords(dataFrame):
     new_row=np.zeros(len(dataFrame.index))
     dataFrame['keywords']=new_row
-    for index,rows in dataFrame.iterrows():
-        text=rows["text"]
+    for index,row in dataFrame.iterrows():
+        text=row["text"]
         filteredText=''.strip()
-        tokens = ngram_vars["nlp"](text)
+        tokens = ngram_vars["nlp"](text.lower())
         '''tokens = [token
                  for token in tokens
                  if not token.is_stop and not token.is_punct]'''
@@ -96,22 +97,29 @@ def calculateDist(dataset,group_by="month"):
     
     return sophia2_ngram_struct
 
-def view(struct, words, annotate):
+def view(word_distribution, words, annotate, normalize=True): ##to word_distribution
     ngram_dictionary={}
     for palabra in words:
         ngram_dictionary[palabra]=[]
         keys=[]
-        for key in struct:
-            keys.append(key)
-            ngram_dictionary[palabra].append(struct[key]["dictionary"][palabra])
+        if normalize==True:
+            for key in word_distribution:
+                keys.append(key)
+                ngram_dictionary[palabra].append(word_distribution[key]["dictionary"][palabra]/word_distribution[key]["total_news"])
+        else:    
+            for key in word_distribution:
+                keys.append(key)
+                ngram_dictionary[palabra].append(word_distribution[key]["dictionary"][palabra])
         plt.plot(keys,ngram_dictionary[palabra],label=palabra)
         plt.legend(loc=5, bbox_to_anchor=(1.3, 0.5), fancybox=True, shadow=True )
-        plt.title("PySophia NGramViewer")
+        plt.title("PySophia2 NGramViewer")
         if(annotate):
             for xy in zip(keys, ngram_dictionary[palabra]):                                       # <--
-                plt.annotate('%s' % xy[1], xy=xy, textcoords='data')
-    plt.xlabel('Fecha', fontsize=12)
-    plt.ylabel('Apariciones', fontsize=12)
+                plt.annotate(('%.2f' % xy[1]), xy=xy, textcoords='data')
+    plt.xlabel('Date', fontsize=12)
+    plt.ylabel('Frequency', fontsize=12)
+    plt.xticks(rotation=90)
+    plt.rcParams['figure.figsize'] = [7, 7]
     
     
 def get_n_most_freq(freq_struct, n, graph=False):
@@ -146,14 +154,15 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
             x = [x[0] for x in top]
             y = [x[1]/total_news for x in top]
             plt.bar(x,y)
-            plt.title("term frecuency top %i words" %(top_n))
+            plt.title("Term frecuency top %i words" %(top_n))
         return top
     elif words!=None:
         y = []
         for word in words:
             y.append(concept_freq_total[word]/total_news)
         plt.bar(words,y)
-        plt.title("term frecuency bar graph")
+        plt.title("Term frecuency bar graph")
+        plt.xticks(rotation=90)
         
         
 
